% EMOTIONS - beach choice with emotion inducing movie treatments
% The script uses DCE and TOOLS packages available from https://github.com/czaj/
% Mikolaj Czajkowski, mik@czaj.org, 2014-09-28

clear all
clc

global B_backup; % this one is for storing B in case iterations are interrupted with ctrl-c


%% ****************************  loading data  ****************************

EstimOpt.fnameinput = ('emo_data');
DATA = load(EstimOpt.fnameinput);

%% ****************************  data transformations  ****************************


DATA.WQ0 = DATA.WQ == 1;
DATA.WQ1 = DATA.WQ == 1;
DATA.WQ2 = DATA.WQ == 2;
DATA.SED0 = DATA.SED == 0;
DATA.SED1 = DATA.SED == 1;
DATA.SED2 = DATA.SED == 2;
DATA.FISH0 = DATA.FISH == 0;
DATA.FISH1 = DATA.FISH == 1;
DATA.FISH2 = DATA.FISH == 2;
DATA.DIST = DATA.DIST/100;

DATA.sadhappy_norm = (DATA.sadhappy - mean(DATA.sadhappy))./std(DATA.sadhappy);
DATA.badgood_norm = (DATA.badgood - mean(DATA.badgood))./std(DATA.badgood);
% DATA.relaxedtense_norm = (DATA.relaxedtense - mean(DATA.relaxedtense))./std(DATA.relaxedtense);

DATA.sadhappy_abs = abs(DATA.sadhappy-4);
DATA.badgood_abs = abs(DATA.badgood-4);
% DATA.relaxedtense_abs = abs(DATA.relaxedtense-4);

DATA.sadhappy_abs_norm = (DATA.sadhappy_abs - mean(DATA.sadhappy_abs))./std(DATA.sadhappy_abs);
DATA.badgood_abs_norm = (DATA.badgood_abs - mean(DATA.badgood_abs))./std(DATA.badgood_abs);
% DATA.relaxedtense_abs_norm = (DATA.relaxedtense_abs - mean(DATA.relaxedtense_abs))./std(DATA.relaxedtense_abs);

%% ****************************  model specification  ****************************


DATA.Y = DATA.ANS;

% A:
DATA.X = [DATA.WQ1, DATA.WQ2, DATA.SED1, DATA.SED0, DATA.FISH1, DATA.FISH2, DATA.SQ, DATA.DIST];
EstimOpt.NamesA = {'WQ1';'WQ2';'SED1';'SED0';'FISH1';'FISH2';'SQ';'DIST'};

% B:
% DATA.X = matInt(DATA.X,[DATA.treatment == 0, DATA.treatment == -1, DATA.treatment == 1]);
% EstimOpt.NamesA = {'WQ1_0';'WQ1_s';'WQ1_h';'WQ2_0';'WQ2_s';'WQ2_h';'SED1_0';'SED1_s';'SED1_h';'SED0';'SED0_s';'SED0_h';'FISH1_0';'FISH1_s';'FISH1_h';'FISH2_0';'FISH2_s';'FISH2_h';'SQ_0';'SQ_s';'SQ_h';'DIST_0';'DIST_s';'DIST_h'};

% B1: 
% INPUT.Xm = [DATA.treatment==-1, DATA.treatment==1];
% EstimOpt.NamesM = {'sad','happy'};

% B2:
% DATA.X = matInt(DATA.X,[ones(size(DATA.treatment,1),1), DATA.treatment == -1, DATA.treatment == 1]);
% EstimOpt.NamesA = {'WQ1';'WQ1_s';'WQ1_h';'WQ2';'WQ2_s';'WQ2_h';'SED1';'SED1_s';'SED1_h';'SED0';'SED0_s';'SED0_h';'FISH1';'FISH1_s';'FISH1_h';'FISH2';'FISH2_s';'FISH2_h';'SQ';'SQ_s';'SQ_h';'DIST';'DIST_s';'DIST_h'};

% C:
% DATA.X = matInt(DATA.X,[DATA.treatment == 0, DATA.treatment == -1 | DATA.treatment == 1]);
% EstimOpt.NamesA = {'WQ1_0';'WQ1_e';'WQ2_0';'WQ2_e';'SED1_0';'SED1_e';'SED_0';'SED_e';'FISH1_0';'FISH1_e';'FISH2_0';'FISH2_e';'SQ_0';'SQ_e';'DIST_0';'DIST_e'};

% C2:
% DATA.X = matInt(DATA.X,[ones(size(DATA.treatment,1),1), DATA.treatment == -1 | DATA.treatment == 1]);
% EstimOpt.NamesA = {'WQ1';'WQ1_e';'WQ2';'WQ2_e';'SED1';'SED1_e';'SED';'SED_e';'FISH1';'FISH1_e';'FISH2';'FISH2_e';'SQ';'SQ_e';'DIST';'DIST_e'};

% D:
% DATA.Xs = [DATA.treatment==-1, DATA.treatment==1];
% EstimOpt.NamesS = {'sad';'happy'};
% INPUT.Xs = DATA.Xs;

% E:
% DATA.Xs = [DATA.treatment==-1 | DATA.treatment==1];
% EstimOpt.NamesS = {'emotional treatment'};
% INPUT.Xs = DATA.Xs;

% F:
% DATA.X = matInt(DATA.X,[ones(size(DATA.treatment)), DATA.sadhappy_norm, DATA.badgood_norm]);
% EstimOpt.NamesA = {'WQ1';'WQ1_sh';'WQ1_bg';'WQ2';'WQ2_sh';'WQ2_bg';'SED1';'SED1_sh';'SED1_bg';'SED0';'SED0_sh';'SED0_bg';'FISH1';'FISH1_sh';'FISH1_bg';'FISH2';'FISH2_sh';'FISH2_bg';'SQ';'SQ_sh';'SQ_bg';'DIST';'DIST_sh';'DIST_bg'};

% G:
% DATA.X = matInt(DATA.X,[ones(size(DATA.treatment)), DATA.sadhappy_abs_norm, DATA.badgood_abs_norm, DATA.relaxedtense_abs_norm]);
% EstimOpt.NamesA = {'WQ1';'WQ1_sh';'WQ1_bg';'WQ1_rt';'WQ2';'WQ2_sh';'WQ2_bg';'WQ2_rt';'SED1';'SED1_sh';'SED1_bg';'SED1_rt';'SED0';'SED0_sh';'SED0_bg';'SED0_rt';'FISH1';'FISH1_sh';'FISH1_bg';'FISH1_rt';'FISH2';'FISH2_sh';'FISH2_bg';'FISH2_rt';'SQ';'SQ_sh';'SQ_bg';'SQ_rt';'DIST';'DIST_sh';'DIST_bg';'DIST_rt'};

% H:
% DATA.Xs = [DATA.sadhappy_norm, DATA.badgood_norm, DATA.relaxedtense_norm];
% EstimOpt.NamesS = {'sad-happy (norm.)', 'bad-good (norm.)', 'relaxed-tense (norm.)'};
% INPUT.Xs = DATA.Xs;

% I:
% DATA.Xs = [DATA.sadhappy_abs_norm, DATA.badgood_abs_norm, DATA.relaxedtense_abs_norm];
% EstimOpt.NamesS = {'sad-happy (abs. norm.)', 'bad-good (abs. norm.)', 'relaxed-tense (abs. norm.)'};
% INPUT.Xs = DATA.Xs;

% J:
% EstimOpt.NLatent = 3;
% INPUT.Xmea = [DATA.sadhappy, DATA.badgood, DATA.relaxedtense];
% EstimOpt.NamesMea = {'sad-happy', 'bad-good', 'relaxed-tense'};
% EstimOpt.MeaMatrix = [1 0 0; 0 1 0; 0 0 1];
% EstimOpt.MeaSpecMatrix = [2];

% K:
% EstimOpt.NLatent = 3;
% INPUT.Xmea = [DATA.sadhappy, DATA.badgood, DATA.relaxedtense];
% EstimOpt.NamesMea = {'sad-happy', 'bad-good', 'relaxed-tense'};
% EstimOpt.MeaMatrix = [1 0 0; 0 1 0; 0 0 1];
% EstimOpt.MeaSpecMatrix = [2];
% INPUT.Xmea_exp = [DATA.treatment==-1 , DATA.treatment==1];
% EstimOpt.NamesMeaExp = {'sad';'happy'};
% INPUT.Xstr = [DATA.treatment==-1 , DATA.treatment==1];
% EstimOpt.NamesStr = {'sad';'happy'};


% INPUT.Xm = [DATA.vcons_norm, DATA.theatre12c > 0, DATA.theatre12c_log0];
% EstimOpt.NamesM = {'obj. cons. (norm.)','theater visits > 0','log(theater visits 0+)'}; %'theater visits norm.'


%% ****************************  loading & specifying input ****************************


INPUT.Y = DATA.ANS;
INPUT.Xa = DATA.X;
% INPUT.Xc = DATA.Xc;
% INPUT.Xs = DATA.Xs;
% INPUT.MissingInd = DATA.noans;


%% ****************************  sample characteristics ****************************

EstimOpt.NCT = 8; % Number of choice tasks per person 
EstimOpt.NAlt = 3; % Number of alternatives
EstimOpt.NP = length(INPUT.Y)/EstimOpt.NCT/EstimOpt.NAlt;


%% **************************** estimation and optimization options ****************************

% EstimOpt.eps = 1.e-12; % overall precision level

[INPUT, Results, EstimOpt, OptimOpt] = DataCleanDCE(INPUT,EstimOpt);

EstimOpt.NRep = 1e4; % number of draws for numerical simulation
% OptimOpt.MaxIter = 1e3; % maximum number of iterations

% OptimOpt.Algorithm = 'trust-region'; %'quasi-newton'; % 'trust-region'
% EstimOpt.NumGrad = 1; % 1
% OptimOpt.GradObj = 'on'; % 'off'
% OptimOpt.FinDiffType = 'central'; % 'forward'
% OptimOpt.Hessian = 'user-supplied'; % 'off'
% EstimOpt.HessEstFix = 1; % 0 = use optimization Hessian, 1 = use jacobian-based (BHHH) Hessian, 2 - use high-precision jacobian-based (BHHH) Hessian 3 - use numerical Hessian

% EstimOpt.DRAWSkeep = 1;


%% **************************** MNL ****************************

Results.MNL = MNL(INPUT,Results,EstimOpt,OptimOpt);
xlswrite('MNL.xls', Results.MNL.R_out) 


%% ************************** MXL_d *******************************

% specifications with other distributions (unused):
% EstimOpt.Dist = [1 1 1 0 0 1 1 0 1];
% Dist LN: -1913.2801
% + fish: -1909.6240
% - sed: -1909.9443
% + wq: -1909.6239

Results.MXL_d = MXL(INPUT,Results,EstimOpt,OptimOpt);
xlswrite('MXL_d.xls', Results.MXL_d.R_out)


%% ************************** GMNL *******************************

% A: 
% Results.GMXL_d.b0 = [Results.MXL_d.bhat;0;0];
% EstimOpt.BActive = [ones(size(Results.GMXL_d.b0))];
% EstimOpt.BActive(9:16) = 0;
% Results.GMXL_d.b0 = Results.GMXL_d.b0 .* EstimOpt.BActive;
% EstimOpt.BActive(end) = [];
% Results.GMXL_d.b0 = [2.20985604047794;2.57494255069826;0.743165068210653;0.848056715852395;0.432495121024845;0.409880383923008;0.995777116349738;-1.21189788710675;0;0;0;0;0;0;0;0;1.25203551180309;0];

% B: 
% Results.GMXL_d.b0 = [Results.MXL_d.bhat;0;0];
% EstimOpt.BActive = [ones(size(Results.GMXL_d.b0))];
% EstimOpt.BActive = [ones(size(Results.GMXL_d.b0))];
% EstimOpt.BActive(25:48) = 0;
% Results.GMXL_d.b0 = Results.GMXL_d.b0 .* EstimOpt.BActive;
% EstimOpt.BActive(end) = [];
% Results.GMXL_d.b0 = [2.08837800834544;2.26840463682365;2.30199371378599;2.40597994012684;2.79925006224658;2.56608121664272;0.885116722680373;0.761711012111735;0.571593952897953;0.928852069609721;1.02541436648707;0.591481212117404;0.513420537574550;0.378072261279964;0.428016650347785;0.481270481748137;0.308474446152226;0.473812775698845;0.828258271124825;1.16890595412287;1.03110499300923;-1.32611143716860;-1.11162132565002;-1.19777843780794;0;0;0;0;0;0;0;0;0;0;0;0;0;0;0;0;0;0;0;0;0;0;0;0;1.23203122212986;0];

% C: 
% Results.GMXL_d.b0 = [Results.MXL_d.bhat;0;0];
% EstimOpt.BActive = [ones(size(Results.GMXL_d.b0))];
% EstimOpt.BActive = [ones(size(Results.GMXL_d.b0))];
% EstimOpt.BActive(17:32) = 0;
% Results.GMXL_d.b0 = Results.GMXL_d.b0 .* EstimOpt.BActive;
% EstimOpt.BActive(end) = [];
% Results.GMXL_d.b0 = [2.08837800834544;2.26840463682365;2.30199371378599;2.40597994012684;2.79925006224658;2.56608121664272;0.885116722680373;0.761711012111735;0.571593952897953;0.928852069609721;1.02541436648707;0.591481212117404;0.513420537574550;0.378072261279964;0.428016650347785;0.481270481748137;0.308474446152226;0.473812775698845;0.828258271124825;1.16890595412287;1.03110499300923;-1.32611143716860;-1.11162132565002;-1.19777843780794;0;0;0;0;0;0;0;0;0;0;0;0;0;0;0;0;0;0;0;0;0;0;0;0;1.23203122212986;0];

% D: 
% Results.GMXL_d.b0 = [Results.MXL_d.bhat;0;0];
% EstimOpt.BActive = [ones(size(Results.GMXL_d.b0))];
% EstimOpt.BActive = [ones(size(Results.GMXL_d.b0))];
% EstimOpt.BActive(9:16) = 0;
% Results.GMXL_d.b0 = Results.GMXL_d.b0 .* EstimOpt.BActive;
% EstimOpt.BActive(end) = [];
% Results.GMXL_d.b0 = [2.18157089381535;2.54447296998087;0.734884015579913;0.840237838705618;0.427588972105315;0.405355939721324;0.985423763229598;-1.19614669304875;0;0;0;0;0;0;0;0;0.0425781312377287;-0.00895047029780105;1.23665990915618;0];

% E: 
% Results.GMXL_d.b0 = [Results.MXL_d.bhat;0;0];
% EstimOpt.BActive = [ones(size(Results.GMXL_d.b0))];
% EstimOpt.BActive = [ones(size(Results.GMXL_d.b0))];
% EstimOpt.BActive(9:16) = 0;
% Results.GMXL_d.b0 = Results.GMXL_d.b0 .* EstimOpt.BActive;
% EstimOpt.BActive(end) = [];
% Results.GMXL_d.b0 = [2.18465836794246;2.54584941854033;0.733951499077098;0.838068668718241;0.427530379324545;0.405304753724613;0.984941877703046;-1.19744087799078;0;0;0;0;0;0;0;0;0.0170961242946797;1.25041051346712;0];

% F: 
% Results.GMXL_d.b0 = [Results.MXL_d.bhat;0;0];
% EstimOpt.BActive = [ones(size(Results.GMXL_d.b0))];
% EstimOpt.BActive = [ones(size(Results.GMXL_d.b0))];
% EstimOpt.BActive(33:64) = 0;
% Results.GMXL_d.b0 = Results.GMXL_d.b0 .* EstimOpt.BActive;
% EstimOpt.BActive(end) = [];

% G: 
% Results.GMXL_d.b0 = [Results.MXL_d.bhat;0;0];
% EstimOpt.BActive = [ones(size(Results.GMXL_d.b0))];
% EstimOpt.BActive(25:48) = 0;
% Results.GMXL_d.b0 = Results.GMXL_d.b0 .* EstimOpt.BActive;
% EstimOpt.BActive(end) = [];


% Results.SMNL = GMXL(INPUT,Results,EstimOpt,OptimOpt);
% xlswrite('SMNL.xls', Results.SMNL.R_out)


%% ************************** GMXL *******************************


% B_backup = [];
% EstimOpt.BActive = [];

% Results.GMXL_d = GMXL(INPUT,Results,EstimOpt,OptimOpt);
% xlswrite('GMXL_d.xls', Results.GMXL_d.R_out)
