% EMOTIONS - beach choice with emotion inducing movie treatments
% Mikolaj Czajkowski, miq@wne.uw.edu.pl, 2014-09-28

clear all
clc

global B_backup; % this one is for storing B in case iterations are interrupted with ctrl-c


%% ****************************  loading data  ****************************

EstimOpt.fnameinput = ('emo_data');
DATA = load(EstimOpt.fnameinput);

%% ****************************  data transformations  ****************************


DATA.WQ0 = DATA.WQ == 1;
DATA.WQ1 = DATA.WQ == 1;
DATA.WQ2 = DATA.WQ == 2;
DATA.SED0 = DATA.SED == 0;
DATA.SED1 = DATA.SED == 1;
DATA.SED2 = DATA.SED == 2;
DATA.FISH0 = DATA.FISH == 0;
DATA.FISH1 = DATA.FISH == 1;
DATA.FISH2 = DATA.FISH == 2;
DATA.DIST = DATA.DIST/100;

DATA.sadhappy_norm = (DATA.sadhappy - mean(DATA.sadhappy))./std(DATA.sadhappy);
DATA.badgood_norm = (DATA.badgood - mean(DATA.badgood))./std(DATA.badgood);
% DATA.relaxedtense_norm = (DATA.relaxedtense - mean(DATA.relaxedtense))./std(DATA.relaxedtense);

DATA.sadhappy_abs = abs(DATA.sadhappy-4);
DATA.badgood_abs = abs(DATA.badgood-4);
% DATA.relaxedtense_abs = abs(DATA.relaxedtense-4);

DATA.sadhappy_abs_norm = (DATA.sadhappy_abs - mean(DATA.sadhappy_abs))./std(DATA.sadhappy_abs);
DATA.badgood_abs_norm = (DATA.badgood_abs - mean(DATA.badgood_abs))./std(DATA.badgood_abs);
% DATA.relaxedtense_abs_norm = (DATA.relaxedtense_abs - mean(DATA.relaxedtense_abs))./std(DATA.relaxedtense_abs);

%% ****************************  model specification  ****************************


DATA.Y = DATA.ANS;

% A:
DATA.X = [DATA.WQ1, DATA.WQ2, DATA.SED1, DATA.SED0, DATA.FISH1, DATA.FISH2, DATA.SQ, DATA.DIST];
EstimOpt.NamesA = {'WQ1';'WQ2';'SED1';'SED0';'FISH1';'FISH2';'SQ';'DIST'};

% B:
% DATA.X = matInt(DATA.X,[DATA.treatment == 0, DATA.treatment == -1, DATA.treatment == 1]);
% EstimOpt.NamesA = {'WQ1_0';'WQ1_s';'WQ1_h';'WQ2_0';'WQ2_s';'WQ2_h';'SED1_0';'SED1_s';'SED1_h';'SED0';'SED0_s';'SED0_h';'FISH1_0';'FISH1_s';'FISH1_h';'FISH2_0';'FISH2_s';'FISH2_h';'SQ_0';'SQ_s';'SQ_h';'DIST_0';'DIST_s';'DIST_h'};

% INPUT.Xm = [DATA.vcons_norm, DATA.theatre12c > 0, DATA.theatre12c_log0];
% EstimOpt.NamesM = {'obj. cons. (norm.)','theater visits > 0','log(theater visits 0+)'}; %'theater visits norm.'


%% ****************************  loading & specifying input ****************************


INPUT.Y = DATA.ANS(DATA.CT<5);
INPUT.Xa = DATA.X(DATA.CT<5,:);
% INPUT.Xc = DATA.Xc;
% INPUT.Xs = DATA.Xs;
% INPUT.MissingInd = DATA.noans;


%% ****************************  sample characteristics ****************************

EstimOpt.NCT = 4; % Number of choice tasks per person 
EstimOpt.NAlt = 3; % Number of alternatives
EstimOpt.NP = length(INPUT.Y)/EstimOpt.NCT/EstimOpt.NAlt;


%% **************************** estimation and optimization options ****************************

% EstimOpt.eps = 1.e-12; % overall precision level

[INPUT, Results, EstimOpt, OptimOpt] = DataCleanDCE(INPUT,EstimOpt);

EstimOpt.NRep = 1e4; % number of draws for numerical simulation
% OptimOpt.MaxIter = 1e3; % maximum number of iterations

% OptimOpt.Algorithm = 'trust-region'; %'quasi-newton'; % 'trust-region'
% EstimOpt.NumGrad = 1; % 1
% OptimOpt.GradObj = 'on'; % 'off'
% OptimOpt.FinDiffType = 'central'; % 'forward'
% OptimOpt.Hessian = 'user-supplied'; % 'off'
EstimOpt.HessEstFix = 1; % 0 = use optimization Hessian, 1 = use jacobian-based (BHHH) Hessian, 2 - use high-precision jacobian-based (BHHH) Hessian 3 - use numerical Hessian

% EstimOpt.DRAWSkeep = 1;


%% **************************** MNL ****************************

Results.MNL = MNL(INPUT,Results,EstimOpt,OptimOpt);
xlswrite('MNL_A4xls', Results.MNL.R_out) 


%% ************************** MXL_d *******************************

% EstimOpt.Dist = [1 1 1 0 0 1 1 0 1];

% A: -1913.9133
% Results.MXL_d.bhat = [2.62451903021673;3.22658482790629;0.998373288485564;1.21949252021328;0.759899949048028;0.874577491267826;0.862054064379392;-1.89656122740465;0.00193394592404235;-0.0133321068661717;0.0108797991003080;0.785911066589809;0.223698734049512;0.903598742646339;1.63669185848246;1.24895936784698];

Results.MXL_d = MXL(INPUT,Results,EstimOpt,OptimOpt);
xlswrite('MXL_A4.xls', Results.MXL_d.R_out)


