% EMOTIONS - beach choice with emotion inducing movie treatments
% The script uses DCE and TOOLS packages available from https://github.com/czaj/
% Mikolaj Czajkowski, mik@czaj.org, 2014-09-28

clear all
clc

global B_backup; % this one is for storing B in case iterations are interrupted with ctrl-c


%% ****************************  loading data  ****************************

EstimOpt.fnameinput = ('emo_data');
DATA = load(EstimOpt.fnameinput);

%% ****************************  data transformations  ****************************


DATA.WQ0 = DATA.WQ == 1;
DATA.WQ1 = DATA.WQ == 1;
DATA.WQ2 = DATA.WQ == 2;
DATA.SED0 = DATA.SED == 0;
DATA.SED1 = DATA.SED == 1;
DATA.SED2 = DATA.SED == 2;
DATA.FISH0 = DATA.FISH == 0;
DATA.FISH1 = DATA.FISH == 1;
DATA.FISH2 = DATA.FISH == 2;
DATA.DIST = DATA.DIST/100;

DATA.sadhappy_norm = (DATA.sadhappy - mean(DATA.sadhappy))./std(DATA.sadhappy);
DATA.badgood_norm = (DATA.badgood - mean(DATA.badgood))./std(DATA.badgood);
% DATA.relaxedtense_norm = (DATA.relaxedtense - mean(DATA.relaxedtense))./std(DATA.relaxedtense);

DATA.sadhappy_abs = abs(DATA.sadhappy-4);
DATA.badgood_abs = abs(DATA.badgood-4);
% DATA.relaxedtense_abs = abs(DATA.relaxedtense-4);

DATA.sadhappy_abs_norm = (DATA.sadhappy_abs - mean(DATA.sadhappy_abs))./std(DATA.sadhappy_abs);
DATA.badgood_abs_norm = (DATA.badgood_abs - mean(DATA.badgood_abs))./std(DATA.badgood_abs);
% DATA.relaxedtense_abs_norm = (DATA.relaxedtense_abs - mean(DATA.relaxedtense_abs))./std(DATA.relaxedtense_abs);

DATA.trips_norm = DATA.tripsperyear ./ std(DATA.tripsperyear);
DATA.trips_norm = DATA.trips_norm - mean(DATA.trips_norm);

DATA.trips = DATA.tripsperyear;

%% ****************************  model specification  ****************************


DATA.Y = DATA.ANS;

% A:
DATA.X = [DATA.WQ1, DATA.WQ2, DATA.SED1, DATA.SED0, DATA.FISH1, DATA.FISH2, DATA.SQ, DATA.DIST];
EstimOpt.NamesA = {'WQ1';'WQ2';'SED1';'SED0';'FISH1';'FISH2';'SQ';'DIST'};

% B:
% DATA.X = matInt(DATA.X,[DATA.treatment == 0, DATA.treatment == -1, DATA.treatment == 1]);
% EstimOpt.NamesA = {'WQ1_0';'WQ1_s';'WQ1_h';'WQ2_0';'WQ2_s';'WQ2_h';'SED1_0';'SED1_s';'SED1_h';'SED0';'SED0_s';'SED0_h';'FISH1_0';'FISH1_s';'FISH1_h';'FISH2_0';'FISH2_s';'FISH2_h';'SQ_0';'SQ_s';'SQ_h';'DIST_0';'DIST_s';'DIST_h'};

% B1:
% DATA.X = matInt(DATA.X,[ones(size(DATA.treatment,1),1), DATA.treatment == -1, DATA.treatment == 1]);
% EstimOpt.NamesA = {'WQ1';'WQ1_s';'WQ1_h';'WQ2';'WQ2_s';'WQ2_h';'SED1';'SED1_s';'SED1_h';'SED0';'SED0_s';'SED0_h';'FISH1';'FISH1_s';'FISH1_h';'FISH2';'FISH2_s';'FISH2_h';'SQ';'SQ_s';'SQ_h';'DIST';'DIST_s';'DIST_h'};

% B2: 
% INPUT.Xm = [DATA.treatment==-1, DATA.treatment==1];
% EstimOpt.NamesM = {'sad','happy'};

% C:
% DATA.X = matInt(DATA.X,[DATA.treatment == 0, DATA.treatment == -1 | DATA.treatment == 1]);
% EstimOpt.NamesA = {'WQ1_0';'WQ1_e';'WQ2_0';'WQ2_e';'SED1_0';'SED1_e';'SED_0';'SED_e';'FISH1_0';'FISH1_e';'FISH2_0';'FISH2_e';'SQ_0';'SQ_e';'DIST_0';'DIST_e'};

% D:
% DATA.Xs = [DATA.treatment==-1, DATA.treatment==1];
% EstimOpt.NamesS = {'sad';'happy'};
% INPUT.Xs = DATA.Xs;

% E:
% DATA.Xs = [DATA.treatment==-1 | DATA.treatment==1];
% EstimOpt.NamesS = {'emotional treatment'};
% INPUT.Xs = DATA.Xs;

% F:
% DATA.X = matInt(DATA.X,[ones(size(DATA.treatment)), DATA.sadhappy_norm, DATA.badgood_norm]);
% EstimOpt.NamesA = {'WQ1';'WQ1_sh';'WQ1_bg';'WQ2';'WQ2_sh';'WQ2_bg';'SED1';'SED1_sh';'SED1_bg';'SED0';'SED0_sh';'SED0_bg';'FISH1';'FISH1_sh';'FISH1_bg';'FISH2';'FISH2_sh';'FISH2_bg';'SQ';'SQ_sh';'SQ_bg';'DIST';'DIST_sh';'DIST_bg'};

% G:
% DATA.X = matInt(DATA.X,[ones(size(DATA.treatment)), DATA.sadhappy_abs_norm, DATA.badgood_abs_norm]);
% EstimOpt.NamesA = {'WQ1';'WQ1_sh';'WQ1_bg';'WQ2';'WQ2_sh';'WQ2_bg';'SED1';'SED1_sh';'SED1_bg';'SED0';'SED0_sh';'SED0_bg';'FISH1';'FISH1_sh';'FISH1_bg';'FISH2';'FISH2_sh';'FISH2_bg';'SQ';'SQ_sh';'SQ_bg';'DIST';'DIST_sh';'DIST_bg'};

% H:
% DATA.Xs = [DATA.sadhappy_norm, DATA.badgood_norm];
% EstimOpt.NamesS = {'sad-happy (norm.)', 'bad-good (norm.)'};
% INPUT.Xs = DATA.Xs;

% I:
% DATA.Xs = [DATA.sadhappy_abs_norm, DATA.badgood_abs_norm];
% EstimOpt.NamesS = {'sad-happy (abs. norm.)', 'bad-good (abs. norm.)'};
% INPUT.Xs = DATA.Xs;


INPUT.Xm = [DATA.trips_norm];
EstimOpt.NamesM = {'no. of trips (norm.)'}; %'theater visits norm.'


%% ****************************  loading & specifying input ****************************


INPUT.Y = DATA.ANS;
INPUT.Xa = DATA.X;
% INPUT.Xc = DATA.Xc;
% INPUT.Xs = DATA.Xs;
% INPUT.MissingInd = DATA.noans;


%% ****************************  sample characteristics ****************************

EstimOpt.NCT = 8; % Number of choice tasks per person 
EstimOpt.NAlt = 3; % Number of alternatives
EstimOpt.NP = length(INPUT.Y)/EstimOpt.NCT/EstimOpt.NAlt;


%% **************************** estimation and optimization options ****************************

% EstimOpt.eps = 1.e-12; % overall precision level

[INPUT, Results, EstimOpt, OptimOpt] = DataCleanDCE(INPUT,EstimOpt);

EstimOpt.NRep = 1e4; % number of draws for numerical simulation
% OptimOpt.MaxIter = 1e3; % maximum number of iterations

% OptimOpt.Algorithm = 'trust-region'; %'quasi-newton'; % 'trust-region'
% EstimOpt.NumGrad = 1; % 1
% OptimOpt.GradObj = 'on'; % 'off'
% OptimOpt.FinDiffType = 'central'; % 'forward'
% OptimOpt.Hessian = 'user-supplied'; % 'off'
% EstimOpt.HessEstFix = 0; % 0 = use optimization Hessian, 1 = use jacobian-based (BHHH) Hessian, 2 - use high-precision jacobian-based (BHHH) Hessian 3 - use numerical Hessian

% EstimOpt.DRAWSkeep = 1;


%% **************************** MNL ****************************

Results.MNL = MNL(INPUT,Results,EstimOpt,OptimOpt);
xlswrite('MNL_use.xls', Results.MNL.R_out) 


%% ************************** MXL_d *******************************

Results.MXL_d = MXL(INPUT,Results,EstimOpt,OptimOpt);
xlswrite('MXL_use.xls', Results.MXL_d.R_out)



